;                       Configure the DOS-III Processor.
;
;
; This include file configures the CPU and I/O card cage to contain the
; necessary device interfaces in the proper card slots.  It is invoked by the
; DOS-III command files, as follows:
;
;    do pconfig.inc
;
; This file is never invoked directly by the user.
;
; The CPU's I/O card cage is configured as follows:
;
;    SC  Device  Interface Description
;    --  ------  -----------------------------------------------------------
;    10   TBG    12539C Time Base Generator Interface
;    11   DPD    13210A Disc Drive Interface Data Channel
;    12   DPC    13210A Disc Drive Interface Command Channel
;    13   PTR    12597A-002 Tape Reader Interface
;    14   LPS    12653A Line Printer Interface
;    15   TTY    12531C Buffered Teleprinter Interface
;    16   PTP    12597A-005 Tape Punch Interface
;    17   MSD    13183B Digital Magnetic Tape Unit Interface Data Channel
;    20   MSC    13183B Digital Magnetic Tape Unit Interface Command Channel
;
;
; NOTES:
;
;  - Regarding I/O assignments, HP says:
;
;      Interface cards should be assigned to select codes according to the speed
;      of interrupt response required by the I/O device. Interface cards for
;      high-speed devices should be assigned higher priority addresses (i.e.
;      lower select codes) than low-speed devices. Devices requiring privileged
;      interrupt are always assigned to the highest priority addresses (a
;      privileged interrupt bypasses normal interrupt processing to achieve
;      faster response for interrupts having the greatest urgency), while
;      devices using DCPC transfers are assigned the lowest priority addresses.
;      The one exception to this rule is in regard to the moving head system
;      disc controller. For the fastest interrupt response, assign the moving
;      head disc controller to the next available I/O slots after the Time Base
;      Generator.
;
;    (From the RTE-IVB System Manager's Manual, 92068-90006, January 1983.)



; Configure the CPU.
;
; The system generation includes floating-point support, which must be enabled
; specifically for the 2100.

set CPU 2100,32K,FP,IDLE


; Configure and assign the select codes of the required devices.

set ALL DISABLED

set TBG ENABLED,SC=10
set DPD ENABLED,SC=11
set PTR ENABLED,SC=13
set LPS ENABLED,SC=14
set TTY ENABLED,SC=15
set PTP ENABLED,SC=16
set MSD ENABLED,SC=17


; Configure the disc and tape drive interface models.

set DPC 13210
set MSC 13183


; Display the I/O configuration to the system operator.

show CPU IOCAGE
echo
